LiveStream class
M3U8
Constructors
- LiveStream(Map? dict, {Uri? url, String? label})
Properties
-
entries
→ Iterable<
MapEntry< String, dynamic> > -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setter
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
-
keys
→ Iterable<
String> -
no setterinherited
- label → String?
-
no setter
- length → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → Uri?
-
M3U8
no setter
- values → Iterable
-
no setterinherited
Methods
-
clear(
) → void -
inherited
-
containsKey(
Object? key) → bool -
inherited
-
containsValue(
dynamic value) → bool -
Map<String, dynamic>
inherited
-
forEach(
void action(String key, dynamic value)) → void -
inherited
-
getValue(
String key, dynamic defaultValue) → dynamic -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
Object? key) → dynamic -
inherited
-
removeWhere(
bool test(String key, dynamic value)) → void -
inherited
-
setValue(
String key, dynamic value) → void -
inherited
-
toMap(
) → Map -
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool - The equality operator.
-
operator [](
Object? key) → dynamic -
inherited
-
operator []=(
String key, dynamic value) → void -
inherited